#!/usr/bin/env python

from distutils.core import setup

setup(
    name='lauyaml',
    version='0.1.0',
    description='No full-featured yaml parse library',
    author='Liqiang Lau',
    author_email='liqianglau@outlook.com',
    url='https://liqiang.io/opensource/python/pyaml',
    package='pyaml',
    package_dir={'pyaml': 'pyaml'}
)
